==> haskell-lua-arbitrary-1.0.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lua-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lua-arbitrary
version:              1.0.1
visibility:           public
id:                   lua-arbitrary-1.0.1-52sBnpVvk42JwRhcWxHGS
key:                  lua-arbitrary-1.0.1-52sBnpVvk42JwRhcWxHGS
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2022 Albert Krewinkel

maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Arbitrary instances for Lua types.
description:
    Provides instances for QuickCheck'\''s \"Arbitrary\"
    typeclass.

category:             Foreign
abi:                  391119dad8da0304a44c7593d78132f9
exposed:              True
exposed-modules:      Lua.Arbitrary
import-dirs:          /usr/lib/ghc-9.0.2/site-local/lua-arbitrary-1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/lua-arbitrary-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/lua-arbitrary-1.0.1
hs-libraries:         HSlua-arbitrary-1.0.1-52sBnpVvk42JwRhcWxHGS
depends:
    QuickCheck-2.14.2-6NzOqgeLJOJL2aV6yCgJTH base-4.15.1.0
    lua-2.0.2-JzvJLllVFL3FdX8uNpNqWB

haddock-interfaces:
    /usr/share/doc/haskell-lua-arbitrary/html/lua-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-lua-arbitrary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lua-arbitrary-1.0.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lua-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lua-arbitrary
version:              1.0.1
visibility:           public
id:                   lua-arbitrary-1.0.1-IjxdG5SRJwAGZUEKPlOGZY
key:                  lua-arbitrary-1.0.1-IjxdG5SRJwAGZUEKPlOGZY
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2022 Albert Krewinkel

maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Arbitrary instances for Lua types.
description:
    Provides instances for QuickCheck'\''s \"Arbitrary\"
    typeclass.

category:             Foreign
abi:                  0624ee9a2acb19b682b4adf1582ac6b8
exposed:              True
exposed-modules:      Lua.Arbitrary
import-dirs:          /usr/lib/ghc-9.0.2/site-local/lua-arbitrary-1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/lua-arbitrary-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/lua-arbitrary-1.0.1
hs-libraries:         HSlua-arbitrary-1.0.1-IjxdG5SRJwAGZUEKPlOGZY
depends:
    QuickCheck-2.14.2-1WQyMS2Rq1aCd8TFPpRr3t base-4.15.1.0
    lua-2.0.2-EsUlr7oSD9s5dY6pnso6b0

haddock-interfaces:
    /usr/share/doc/haskell-lua-arbitrary/html/lua-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-lua-arbitrary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
